@@ -1,5 +1,6 @@
 """Command-line interface."""
 import argparse
+
 from exmc.convert import run
 
 
@@ -7,10 +8,16 @@ def main() -> None:
     """Excel Markdown Converter."""
     parser = argparse.ArgumentParser()
     parser.add_argument(
-        "-d", "--debug", help="print origin text from excel or markdown"
+        "-d",
+        "--debug",
+        help="print origin text from excel or markdown",
+        action="store_true",
     )
     parser.add_argument(
-        "-r", "--reverse", help="convert markdown table str to excel str"
+        "-r",
+        "--reverse",
+        help="convert markdown table str to excel str",
+        action="store_true",
     )
     args = parser.parse_args()
     run(args)
